@@ -54,7 +54,6 @@ module.exports = function (url) {
 
     console.log('若出现不符合的情况:'
         '\n绿色字符为App端相对Server端添加的部分',
-        '\n红色字符为App端相对Server端删除的部分'，
-        '\n灰色字符为App端相对Server端一致的部分',
-);
+        '\n红色字符为App端相对Server端删除的部分',
+        '\n灰色字符为App端相对Server端一致的部分');
 };
\ No newline at end of file
